@@ -13,7 +13,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2009 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2012 Live Networks, Inc.  All rights reserved.
 // Usage Environment
 // Implementation
 
@@ -31,6 +31,12 @@ UsageEnvironment::UsageEnvironment(TaskScheduler& scheduler)
 UsageEnvironment::~UsageEnvironment() {
 }
 
+// By default, we handle 'should not occur'-type library errors by calling abort().  Subclasses can redefine this, if desired.
+void UsageEnvironment::internalError() {
+  abort();
+}
+
+
 TaskScheduler::TaskScheduler() {
 }
 
@@ -43,3 +49,8 @@ void TaskScheduler::rescheduleDelayedTask(TaskToken& task,
   unscheduleDelayedTask(task);
   task = scheduleDelayedTask(microseconds, proc, clientData);
 }
+
+// By default, we handle 'should not occur'-type library errors by calling abort().  Subclasses can redefine this, if desired.
+void TaskScheduler::internalError() {
+  abort();
+}
